/* Define to the name of the distribution.  */
#undef PACKAGE

#undef HAVE_GETTEXT
#undef HAVE_UNISTD_H
#undef HAVE_DIRENT_H
#undef HAVE_FNMATCH_H

/* Define to the version of the distribution.  */
#undef VERSION
#undef SCIGRAPHICA_MAJOR_VERSION
#undef SCIGRAPHICA_MINOR_VERSION
#undef SCIGRAPHICA_MICRO_VERSION
#undef SCIGRAPHICA_INTERFACE_AGE
#undef SCIGRAPHICA_BINARY_AGE
#undef SCIGRAPHICA_VERSION
#undef SCIGRAPHICA_CURRENT
#undef SCIGRAPHICA_REVISION
#undef SCIGRAPHICA_AGE


/* Define to the verbose version info of the distribution.  */
#undef VERSION_INFO

/* Root of the SciGraphica installation */
#undef SCIGRAPHICA_ROOT

/* Viewer for Documentation */
#undef SCIGRAPHICA_DOCVIEWER

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT
#undef GETTEXT_PACKAGE 

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define as the directory to load locale data from.  */
#undef LOCALEDIR

/* The location of the program to use for printing. */
#undef PRINT_COMMAND

#undef HAVE_OPENPTY
#undef HAVE_LOGIN_TTY  
#undef HAVE_SENDMSG

#undef HAVE_STROPTS_H
#undef HAVE_DLFCN_H
#undef HAVE_LIBUTIL

